@@ -1,4 +1,4 @@
-# Options for use within the code for setting and getting PKNCA default options.
+# Options for use within the code for setting and getting PKNCA default options. ####
 
 .PKNCA.option.check <- list(
   adj.r.squared.factor=function(x, default=FALSE, description=FALSE) {
@@ -40,13 +40,16 @@
     x
   },
   auc.method=function(x, default=FALSE, description=FALSE) {
+    choices <- eval(formals(assert_aucmethod)$method)
     if (description)
       return(paste(
         "The method used to calculate the AUC and related statistics.",
-        "Options are 'lin up/log down' and 'linear'."))
+        "Options are:",
+        paste0('"', choices, '"', collapse = ", ")
+      ))
     if (default)
-      return("lin up/log down")
-    match.arg(x, c("lin up/log down", "linear"))
+      return(choices[1])
+    assert_aucmethod(x)
   },
   conc.na=function(x, default=FALSE, description=FALSE) {
     if (description)
@@ -163,6 +166,16 @@
     }
     x
   },
+
+  keep_interval_cols = function(x, default = FALSE, description = FALSE) {
+    if (description)
+      return("What additional columns from the intervals should be kept in the results?")
+    if (default)
+      return(NULL)
+    checkmate::assert_names(x)
+    x
+  },
+
   min.hl.points=function(x, default=FALSE, description=FALSE) {
     if (description)
       return("What is the minimum number of points required to calculate half-life?")
@@ -236,6 +249,16 @@
       warning("min.hl.r.squared is usually >= 0.9")
     x
   },
+
+  progress = function(x, default = FALSE, description = FALSE) {
+    if (description)
+      return("A value to pass to purrr::pmap(.progress = ) to create a progress bar while running")
+    if (default) {
+      return(TRUE)
+    }
+    x
+  },
+
   tau.choices=function(x, default=FALSE, description=FALSE) {
     if (description)
       return(paste(
@@ -277,40 +300,40 @@
     check.interval.specification(x)
   })
 
+# Functions controlling and modifying options ####
+
 #' Set default options for PKNCA functions
 #'
-#' This function will set the default PKNCA options.  If given no
-#' inputs, it will provide the current option set.  If given name/value
-#' pairs, it will set the option (as in the \code{\link{options}}
-#' function).  If given a name, it will return the value for the
-#' parameter.  If given the \code{default} option as true, it will
+#' This function will set the default PKNCA options.  If given no inputs, it
+#' will provide the current option set.  If given name/value pairs, it will set
+#' the option (as in the [options()] function).  If given a name, it will return
+#' the value for the parameter.  If given the `default` option as true, it will
 #' provide the default options.
 #'
-#' Options are either for calculation or summary functions. Calculation
-#' options are required for a calculation function to report a result
-#' (otherwise the reported value will be \code{NA}). Summary options are
-#' used during summarization and are used for assessing what values are
-#' included in the summary.
+#' Options are either for calculation or summary functions. Calculation options
+#' are required for a calculation function to report a result (otherwise the
+#' reported value will be `NA`). Summary options are used during summarization
+#' and are used for assessing what values are included in the summary.
 #'
-#' See the vignette 'Options for Controlling PKNCA' for a current list
-#' of options (\code{vignette("Options-for-Controlling-PKNCA", package="PKNCA")}).
+#' See the vignette 'Options for Controlling PKNCA' for a current list of
+#' options (`vignette("Options-for-Controlling-PKNCA", package="PKNCA")`).
 #'
 #' @param \dots options to set or get the value for
 #' @param default (re)sets all default options
-#' @param check check a single option given, but do not set it (for
-#'   validation of the values when used in another function)
-#' @param name An option name to use with the \code{value}.
-#' @param value An option value (paired with the \code{name}) to set or
-#'   check (if \code{NULL}, ).
-#' @return If...
+#' @param check check a single option given, but do not set it (for validation
+#'   of the values when used in another function)
+#' @param name An option name to use with the `value`.
+#' @param value An option value (paired with the `name`) to set or check (if
+#'   `NULL`, ).
+#' @returns If...
 #' \describe{
 #'   \item{no arguments are given}{returns the current options.}
-#'   \item{a value is set (including the defaults)}{returns \code{NULL}}
+#'   \item{a value is set (including the defaults)}{returns `NULL`}
 #'   \item{a single value is requested}{the current value of that option is returned as a scalar}
 #'   \item{multiple values are requested}{the current values of those options are returned as a list}
 #' }
 #' @family PKNCA calculation and summary settings
-#' @seealso \code{\link{PKNCA.options.describe}}
+#' @seealso [PKNCA.options.describe()]
 #' @examples
 #'
 #' PKNCA.options()
@@ -397,14 +420,15 @@ PKNCA.options <- function(..., default=FALSE, check=FALSE, name, value) {
 #' option.
 #'
 #' @param name The option name requested.
-#' @param value A value to check for the option (\code{NULL} to choose not to
-#'   check the value).
-#' @param options The non-default options to choose from.
-#' @return The value of the option first from the \code{options} list and if it
-#'   is not there then from the current settings.
+#' @param value A value to check for the option (`NULL` to choose not to check
+#'   the value).
+#' @param options List of changes to the default PKNCA options (see
+#'   `PKNCA.options()`)
+#' @returns The value of the option first from the `options` list and if it is
+#'   not there then from the current settings.
 #' @family PKNCA calculation and summary settings
 #' @export
-PKNCA.choose.option <- function(name, value=NULL, options=list())
+PKNCA.choose.option <- function(name, value=NULL, options=list()) {
   if (!is.null(value)) {
     PKNCA.options(name=name, value=value, check=TRUE)
   } else if (name %in% names(options)) {
@@ -412,12 +436,13 @@ PKNCA.choose.option <- function(name, value=NULL, options=list())
   } else {
     PKNCA.options(name)
   }
+}
 
 #' Describe a PKNCA.options option by name.
 #'
 #' @param name The option name requested.
 #' @return A character string of the description.
-#' @seealso \code{\link{PKNCA.options}}
+#' @seealso [PKNCA.options()]
 #' @export
 PKNCA.options.describe <- function(name) {
   .PKNCA.option.check[[name]](description=TRUE)
@@ -425,27 +450,24 @@ PKNCA.options.describe <- function(name) {
 
 #' Define how NCA parameters are summarized.
 #'
-#' @param name The parameter name or a vector of parameter names.  It
-#'   must have already been defined (see
-#'   \code{\link{add.interval.col}}).
+#' @param name The parameter name or a vector of parameter names.  It must have
+#'   already been defined (see [add.interval.col()]).
 #' @param description A single-line description of the summary
-#' @param point The function to calculate the point estimate for the
-#'   summary.  The function will be called as \code{point(x)} and must
-#'   return a scalar value (typically a number, NA, or a string).
+#' @param point The function to calculate the point estimate for the summary.
+#'   The function will be called as `point(x)` and must return a scalar value
+#'   (typically a number, NA, or a string).
 #' @param spread Optional.  The function to calculate the spread (or
-#'   variability).  The function will be called as \code{spread(x)} and
-#'   must return a scalar or two-long vector (typically a number, NA, or
-#'   a string).
-#' @param rounding Instructions for how to round the value of point and
-#'   spread.  It may either be a list or a function.  If it is a list,
-#'   then it must have a single entry with a name of either "signif" or
-#'   "round" and a value of the digits to round.  If a function, it is
-#'   expected to return a scalar number or character string with the
-#'   correct results for an input of either a scalar or a two-long
-#'   vector.
+#'   variability).  The function will be called as `spread(x)` and must return a
+#'   scalar or two-long vector (typically a number, NA, or a string).
+#' @param rounding Instructions for how to round the value of point and spread.
+#'   It may either be a list or a function.  If it is a list, then it must have
+#'   a single entry with a name of either "signif" or "round" and a value of the
+#'   digits to round.  If a function, it is expected to return a scalar number
+#'   or character string with the correct results for an input of either a
+#'   scalar or a two-long vector.
 #' @param reset Reset all the summary instructions
-#' @return All current summary settings (invisibly)
-#' @seealso \code{\link{summary.PKNCAresults}}
+#' @returns All current summary settings (invisibly)
+#' @seealso [summary.PKNCAresults()]
 #' @family PKNCA calculation and summary settings
 #' @examples
 #' \dontrun{
