@@ -1,3 +1,22 @@
+#' Get the impute function from either the intervals column or from the method
+#'
+#' @param intervals the data.frame of intervals
+#' @param impute the imputation definition
+#' @return The imputation function vector
+get_impute_method <- function(intervals, impute) {
+  stopifnot(length(impute) == 1)
+  checkmate::assert_data_frame(intervals)
+  if (impute %in% names(intervals)) {
+    impute_funs <- intervals[[impute]]
+  } else if (is.na(impute) && "impute" %in% names(intervals)) {
+    impute_funs <- intervals$impute
+  } else {
+    impute_funs <- impute
+  }
+  checkmate::assert_character(impute_funs)
+  impute_funs
+}
+
 #' Add the imputation column to the intervals, if it is not already there
 #'
 #' @param object The PKNCAdata object to impute data within
@@ -35,7 +54,7 @@ NULL
 #'   time, even if a nonzero concentration exists at that time (usually used
 #'   with single-dose data)
 #' @inheritParams pk.calc.auxc
-#' @param start,end The start and end of the interval
+#' @inheritParams assert_intervaltime_single
 #' @param ... ignored
 #' @export
 PKNCA_impute_method_start_conc0 <- function(conc, time, start=0, ..., options = list()) {
@@ -70,21 +89,31 @@ PKNCA_impute_method_start_cmin <- function(conc, time, start, end, ..., options
 #' @describeIn PKNCA_impute_method Shift a predose concentration to become the
 #'   time zero concentration (only if a time zero concentration does not exist)
 #' @param max_shift The maximum amount of time to shift a concentration forward
-#'   (defaults to 5\% of the interval duration, i.e. \code{0.05*(end - start)})
+#'   (defaults to 5% of the interval duration, i.e. `0.05*(end - start)`, if
+#'   `is.finite(end)`, and when `is.infinite(end)`, defaults to 5% of the time
+#'   from start to `max(time)`)
+#' @inheritParams pk.nca.interval
 #' @export
-PKNCA_impute_method_start_predose <- function(conc, time, start, end, ..., max_shift = NA_real_, options = list()) {
+PKNCA_impute_method_start_predose <- function(conc, time, start, end, conc.group, time.group, ..., max_shift = NA_real_, options = list()) {
   ret <- data.frame(conc = conc, time = time)
   if (is.na(max_shift)) {
-    max_shift <- 0.05 * (end - start)
+    if (is.infinite(end)) {
+      shift_end <- max(time)
+    } else {
+      shift_end <- end
+    }
+    max_shift <- 0.05 * (shift_end - start)
   }
-  mask_zero <- time %in% start
-  if (!any(mask_zero)) {
-    mask_predose <- time < start
+  # determine if the start time is already in the
+  mask_start <- time %in% start
+  if (!any(mask_start)) {
+    mask_predose <- time.group < start
     if (any(mask_predose)) {
-      time_predose <- max(time[mask_predose])
+      time_predose <- max(time.group[mask_predose])
       if ((-time_predose) <= max_shift) {
-        mask_predose_change <- time == time_predose
-        ret$time[mask_predose_change] <- start
+        mask_predose_change <- time.group == time_predose
+        ret_predose <- data.frame(conc = conc.group[mask_predose_change], time = start)
+        ret <- dplyr::bind_rows(ret_predose, ret)
       }
     }
   }
@@ -98,7 +127,7 @@ PKNCA_impute_method_start_predose <- function(conc, time, start, end, ..., max_s
 #' This function is not for use by users of PKNCA.
 #'
 #' @param x The character vector of PKNCA imputation method functions (without
-#'   the \code{PKNCA_impute_method_} part)
+#'   the `PKNCA_impute_method_` part)
 #' @return A list of character vectors of functions to run.
 #' @keywords Internal
 PKNCA_impute_fun_list <- function(x) {
