@@ -23,39 +23,48 @@ test_that("PKNCA_impute_method_start_conc0", {
 test_that("PKNCA_impute_method_start_predose", {
   # No modification if no predose samples
   expect_equal(
-    PKNCA_impute_method_start_predose(conc = 1:3, time = 1:3, start = 0, end = 24),
+    PKNCA_impute_method_start_predose(conc = 1:3, time = 1:3, conc.group = 1:3, time.group = 1:3, start = 0, end = 24),
     data.frame(conc = 1:3, time = 1:3)
   )
   # No modification if time 0 is already present
   expect_equal(
-    PKNCA_impute_method_start_predose(conc = 1:3, time = 0:2, start = 0, end = 24),
+    PKNCA_impute_method_start_predose(conc = 1:3, time = 0:2, conc.group = 1:3, time.group = 0:2, start = 0, end = 24),
     data.frame(conc = 1:3, time = 0:2)
   )
   # Shift happens when time is within max_shift
   expect_equal(
-    PKNCA_impute_method_start_predose(conc = 1:3, time = c(-1, 1:2), start = 0, end = 24),
+    PKNCA_impute_method_start_predose(conc = 2:3, time = 1:2, conc.group = 1:3, time.group = c(-1, 1:2), start = 0, end = 24),
     data.frame(conc = 1:3, time = 0:2)
   )
   # Shift happens when time is equal to max_shift
   expect_equal(
-    PKNCA_impute_method_start_predose(conc = 1:3, time = c(-1.2, 1:2), start = 0, end = 24),
+    PKNCA_impute_method_start_predose(conc = 2:3, time = 1:2, conc.group = 1:3, time.group = c(-1.2, 1:2), start = 0, end = 24),
     data.frame(conc = 1:3, time = 0:2)
   )
   # Shift occurs to a new start
   expect_equal(
-    PKNCA_impute_method_start_predose(conc = 1:3, time = c(-0.3, 1:2), start = 0.5, end = 24),
+    PKNCA_impute_method_start_predose(conc = 2:3, time = 1:2, conc.group = 1:3, time.group = c(-0.3, 1:2), start = 0.5, end = 24),
     data.frame(conc = 1:3, time = c(0.5, 1:2))
   )
   # Shift does not when time is more than max_shift
   expect_equal(
-    PKNCA_impute_method_start_predose(conc = 1:3, time = c(-3, 1:2), start = 0, end = 24),
-    data.frame(conc = 1:3, time = c(-3, 1:2))
+    PKNCA_impute_method_start_predose(conc = 2:3, time = 1:2, conc.group = 1:3, time.group =c(-3, 1:2), start = 0, end = 24),
+    data.frame(conc = 2:3, time = 1:2)
   )
   # max_shift overrides the start/end automation
   expect_equal(
-    PKNCA_impute_method_start_predose(conc = 1:3, time = c(-3, 1:2), max_shift = 3, start = 0, end = 24),
+    PKNCA_impute_method_start_predose(conc = 2:3, time = 1:2, conc.group = 1:3, time.group = c(-3, 1:2), max_shift = 3, start = 0, end = 24),
     data.frame(conc = 1:3, time = 0:2)
   )
+  # shift automation works reasonably even when the end is infinite
+  expect_equal(
+    PKNCA_impute_method_start_predose(conc = 2:4, time = c(1:2, 24), conc.group = 1:4, time.group = c(-1.25, 1:2, 24), start = 0, end = Inf),
+    data.frame(conc = 2:4, time = c(1:2, 24))
+  )
+  expect_equal(
+    PKNCA_impute_method_start_predose(conc = 2:4, time = c(1:2, 24), conc.group = 1:4, time.group = c(-1.2, 1:2, 24), start = 0, end = Inf),
+    data.frame(conc = 1:4, time = c(0:2, 24))
+  )
 })
 
 test_that("PKNCA_impute_method_start_cmin", {
@@ -186,6 +195,21 @@ test_that("add_impute_to_intervals", {
   ))
 })
 
+test_that("PKNCAdata moves imputation to the intervals column, as applicable", {
+  d_conc <- generate.conc(nsub = 1, ntreat = 1, time.points = 1:3, nstudies = 1)
+  o_conc <- PKNCAconc(conc~time, data = d_conc)
+  o_data <- PKNCAdata(o_conc, intervals = data.frame(start = 0, end = 3, auclast = TRUE))
+  # No imputation creates no imputation instructions
+  expect_equal(o_data$impute, NA_character_)
+
+  o_data <- PKNCAdata(o_conc, intervals = data.frame(start = 0, end = 3, auclast = TRUE), impute = "PKNCA_impute_method_start_conc0")
+  expect_equal(o_data$impute, "PKNCA_impute_method_start_conc0")
+  pk.nca(o_data)
+
+  o_data <- PKNCAdata(o_conc, intervals = data.frame(start = 0, end = 3, auclast = TRUE), impute = "start_conc0")
+  expect_equal(o_data$impute, "start_conc0")
+})
+
 # Putting it all together
 test_that("pk.nca with imputation", {
   d_conc <- as.data.frame(datasets::Theoph)[!datasets::Theoph$Time == 0, ]
@@ -222,3 +246,29 @@ test_that("pk.nca with imputation", {
   expect_true(all(is.na(auclast_manualimpute_24)))
   expect_true(!any(is.na(auclast_manualimpute_24.1)))
 })
+
+test_that("start_conc0 imputation works (fix #257)", {
+  d <- data.frame(time=c(0.08, 1, 2, 3, 4),
+                  conc=c(1, 0.5, 0.4, 0.3, 0.2),
+                  subject=1)
+  myconc <- PKNCAconc(data=d, conc~time|subject)
+  mydata <-
+    PKNCAdata(
+      myconc,
+      intervals=
+        data.frame(
+          start=0, end=5,
+          impute="start_conc0",
+          cmax        = TRUE,
+          tmax        = TRUE,
+          aucinf.obs  = TRUE,
+          aucint.last = TRUE,
+          auclast     = TRUE
+        )
+    )
+  suppressMessages(suppressWarnings(
+    myres <- pk.nca(mydata)
+  ))
+  df_myres <- as.data.frame(myres)
+  expect_false(is.na(df_myres$PPORRES[df_myres$PPTESTCD == "auclast"]))
+})
