@@ -1,12 +1,10 @@
-context("Time to steady-state")
-
 test_that("pk.tss.data.prep", {
   conc.test <- 1:5
   time.test <- 0:4
   subject.test <- letters[1:5]
   treatment.test <- LETTERS[1:5]
   time.dosing.test <- 0
-  ## Confirm that any NAs in time.dosing are an error
+  # Confirm that any NAs in time.dosing are an error
   expect_error(
     pk.tss.data.prep(
       conc=conc.test,
@@ -17,7 +15,25 @@ test_that("pk.tss.data.prep", {
     ),
     regexp="time.dosing may not contain any NA values"
   )
-
+  expect_error(
+    pk.tss.data.prep(
+      conc=conc.test,
+      time=time.test,
+      subject.dosing=subject.test,
+      treatment=treatment.test,
+      time.dosing=NA
+    ),
+    regexp="Cannot give subject.dosing without subject"
+  )
+  expect_equal(
+    pk.tss.data.prep(
+      conc=conc.test,
+      time=time.test,
+      time.dosing=0
+    ),
+    data.frame(conc=1, time=0)
+  )
+  
   expect_error(pk.tss.data.prep(conc=conc.test,
                                 time=time.test,
                                 subject=subject.test,
@@ -25,7 +41,7 @@ test_that("pk.tss.data.prep", {
                                 time.dosing=c(0, NA)),
                regexp="time.dosing may not contain any NA values")
 
-  ## Confirm that conc and subject must be the same length
+  # Confirm that conc and subject must be the same length
   expect_error(pk.tss.data.prep(conc=conc.test,
                                 time=time.test,
                                 subject=subject.test[-1],
@@ -33,7 +49,7 @@ test_that("pk.tss.data.prep", {
                                 time.dosing=time.dosing.test),
                regexp="arguments imply differing number of rows: 5, 4")
 
-  ## Confirm that conc and treatment must be the same length
+  # Confirm that conc and treatment must be the same length
   expect_error(pk.tss.data.prep(conc=conc.test,
                                 time=time.test,
                                 subject=subject.test,
@@ -41,8 +57,8 @@ test_that("pk.tss.data.prep", {
                                 time.dosing=time.dosing.test),
                regexp="arguments imply differing number of rows: 5, 4")
 
-  ## If removed down to one treatment, treatment is not a column of
-  ## the output.
+  # If removed down to one treatment, treatment is not a column of
+  # the output.
   expect_equal(pk.tss.data.prep(conc=conc.test,
                                 time=time.test,
                                 subject=subject.test,
@@ -50,22 +66,22 @@ test_that("pk.tss.data.prep", {
                                 time.dosing=time.dosing.test),
                data.frame(conc=1, time=0))
 
-  ## If no treatment is given, it still works.
+  # If no treatment is given, it still works.
   expect_equal(pk.tss.data.prep(conc=conc.test,
                                 time=time.test,
                                 subject=subject.test,
                                 time.dosing=time.dosing.test),
                data.frame(conc=1, time=0))
 
-  ## If no subject is given, it still works
+  # If no subject is given, it still works
   expect_equal(pk.tss.data.prep(conc=conc.test,
                                 time=time.test,
                                 treatment=treatment.test,
                                 time.dosing=time.dosing.test),
                data.frame(conc=1, time=0))
   
-  ## What do we actually expect to get out?
-  ## Check a single row output dropping treatment
+  # What do we actually expect to get out?
+  # Check a single row output dropping treatment
   expect_equal(pk.tss.data.prep(conc=conc.test,
                                 time=time.test,
                                 subject=subject.test,
@@ -74,14 +90,14 @@ test_that("pk.tss.data.prep", {
                                 subject.dosing=subject.test),
                data.frame(time=0, conc=1))
 
-  ## Check a single row output with no treatment given
+  # Check a single row output with no treatment given
   expect_equal(pk.tss.data.prep(conc=conc.test,
                                 time=time.test,
                                 subject=subject.test,
                                 time.dosing=time.dosing.test),
                data.frame(conc=1, time=0))
 
-  ## Check a multi-row output with treatments kept
+  # Check a multi-row output with treatments kept
   conc.test <- 1:10
   time.test <- rep(0:4, 2)
   subject.test <- letters[1:10]
@@ -101,10 +117,10 @@ test_that("pk.tss.data.prep", {
       treatment=factor(c("A", "F")),
       stringsAsFactors=FALSE
     ),
-    check.attributes=FALSE
+    ignore_attr = TRUE
   )
 
-  ## Check a multi-row output with treatments dropped
+  # Check a multi-row output with treatments dropped
   conc.test <- 1:10
   time.test <- rep(0:4, 2)
   subject.test <- letters[1:10]
@@ -124,12 +140,12 @@ test_that("pk.tss.data.prep", {
       subject=factor(c("a", "f")),
       stringsAsFactors=FALSE
     ),
-    check.attributes=FALSE
+    ignore_attr = TRUE
   )
 })
 
-## This data will be used multiple times in testing, and it is
-## nontrivial to create.
+# This data will be used multiple times in testing, and it is
+# nontrivial to create.
 generate.data <- function() {
   set.seed(5)
   tmpdata <-
@@ -155,14 +171,15 @@ generate.data <- function() {
                        (1-exp(log(1-0.9)*time/(tss.mean*exp(tss.re)))))
   tmpdata
 }
-## Note that this graphically represents the test
-## library(latticeExtra)
-## (xyplot(conc~time|treatment,
-##         groups=subject,
-##         data=generate.data(),
-##         type="l") +
-##  layer(panel.abline(h=5, col="gray", lty=2), packets=1) +
-##  layer(panel.abline(h=10, col="gray", lty=2), packets=2))
+
+# Note that this graphically represents the test
+# library(latticeExtra)
+# (xyplot(conc~time|treatment,
+#         groups=subject,
+#         data=generate.data(),
+#         type="l") +
+#  layer(panel.abline(h=5, col="gray", lty=2), packets=1) +
+#  layer(panel.abline(h=10, col="gray", lty=2), packets=2))
 
 test_that("pk.tss.stepwise.linear", {
   tmpdata <- generate.data()
@@ -173,8 +190,8 @@ test_that("pk.tss.stepwise.linear", {
                            treatment=tmpdata$treatment,
                            time.dosing=0:14,
                            verbose=FALSE),
-    data.frame(tss.stepwise.linear=7),
-    info="pk.tss.stepwise.linear 1")
+    data.frame(tss.stepwise.linear=7)
+  )
 
   expect_warning(
     pk.tss.stepwise.linear(conc=tmpdata$conc,
@@ -184,10 +201,36 @@ test_that("pk.tss.stepwise.linear", {
                            min.points=c(3, 4),
                            time.dosing=0:14,
                            verbose=FALSE),
-    regexp="Only first value of min.points is used",
-    info="pk.tss.stepwise.linear 2")
+    regexp="Only first value of min.points is used"
+  )
+
+  expect_error(
+    pk.tss.stepwise.linear(
+      conc=tmpdata$conc,
+      time=tmpdata$time,
+      subject=tmpdata$subject,
+      treatment=tmpdata$treatment,
+      time.dosing=0:14,
+      min.points="A",
+      level="A",
+      verbose=FALSE
+    ),
+    regexp="min.points must be a number"
+  )
+  expect_error(
+    pk.tss.stepwise.linear(
+      conc=tmpdata$conc,
+      time=tmpdata$time,
+      subject=tmpdata$subject,
+      treatment=tmpdata$treatment,
+      time.dosing=0:14,
+      min.points=1,
+      level="A",
+      verbose=FALSE
+    ),
+    regexp="min.points must be at least 3"
+  )
 
-  ## Check the level input
   expect_error(
     pk.tss.stepwise.linear(conc=tmpdata$conc,
                            time=tmpdata$time,
@@ -196,8 +239,8 @@ test_that("pk.tss.stepwise.linear", {
                            time.dosing=0:14,
                            level="A",
                            verbose=FALSE),
-    regexp="level must be a number",
-    info="pk.tss.stepwise.linear 3")
+    regexp="level must be a number"
+  )
 
   expect_error(
     pk.tss.stepwise.linear(conc=tmpdata$conc,
@@ -207,8 +250,8 @@ test_that("pk.tss.stepwise.linear", {
                            time.dosing=0:14,
                            level=2,
                            verbose=FALSE),
-    regexp="level must be between 0 and 1, exclusive",
-    info="pk.tss.stepwise.linear 4")
+    regexp="level must be between 0 and 1, exclusive"
+  )
   
   expect_error(
     pk.tss.stepwise.linear(conc=tmpdata$conc,
@@ -218,8 +261,8 @@ test_that("pk.tss.stepwise.linear", {
                            time.dosing=0:14,
                            level=-1,
                            verbose=FALSE),
-    regexp="level must be between 0 and 1, exclusive",
-    info="pk.tss.stepwise.linear 5")
+    regexp="level must be between 0 and 1, exclusive"
+  )
   expect_error(
     pk.tss.stepwise.linear(conc=tmpdata$conc,
                            time=tmpdata$time,
@@ -228,8 +271,8 @@ test_that("pk.tss.stepwise.linear", {
                            time.dosing=0:14,
                            level=0,
                            verbose=FALSE),
-    regexp="level must be between 0 and 1, exclusive",
-    info="pk.tss.stepwise.linear 6")
+    regexp="level must be between 0 and 1, exclusive"
+  )
   expect_error(
     pk.tss.stepwise.linear(conc=tmpdata$conc,
                            time=tmpdata$time,
@@ -238,8 +281,8 @@ test_that("pk.tss.stepwise.linear", {
                            time.dosing=0:14,
                            level=1,
                            verbose=FALSE),
-    regexp="level must be between 0 and 1, exclusive",
-    info="pk.tss.stepwise.linear 7")
+    regexp="level must be between 0 and 1, exclusive"
+  )
 
   expect_warning(
     pk.tss.stepwise.linear(conc=tmpdata$conc,
@@ -249,10 +292,10 @@ test_that("pk.tss.stepwise.linear", {
                            time.dosing=0:14,
                            level=c(0.95, 0.99),
                            verbose=FALSE),
-    regexp="Only first value of level is being used",
-    info="pk.tss.stepwise.linear 8")
+    regexp="Only first value of level is being used"
+  )
 
-  ## This is mainly to test verbosity
+  # This is mainly to test verbosity
   expect_warning(
     pk.tss.stepwise.linear(conc=tmpdata$conc,
                            time=tmpdata$time,
@@ -261,10 +304,46 @@ test_that("pk.tss.stepwise.linear", {
                            time.dosing=0:14,
                            level=c(0.95, 0.99),
                            verbose=FALSE),
-    regexp="Only first value of level is being used",
-    info="pk.tss.stepwise.linear 9")
+    regexp="Only first value of level is being used"
+  )
 
-  ## Ensure that the first value really is used
+  # Check outputs
+  suppressMessages(
+    withr::with_options(
+      list(try.outFile=nullfile()),
+      expect_message(
+        pk.tss.stepwise.linear(
+          conc=tmpdata$conc,
+          time=tmpdata$time,
+          subject=tmpdata$subject,
+          treatment=tmpdata$treatment,
+          time.dosing=0:14,
+          level=0.8,
+          verbose=TRUE
+        ),
+        regexp="Trying 0"
+      )
+    )
+  )
+  suppressMessages(
+    withr::with_options(
+      list(try.outFile=nullfile()),
+      expect_message(
+        pk.tss.stepwise.linear(
+          conc=tmpdata$conc,
+          time=tmpdata$time,
+          subject=tmpdata$subject,
+          treatment=tmpdata$treatment,
+          time.dosing=0:14,
+          level=0.8,
+          verbose=TRUE
+        ),
+        regexp="Current interval"
+      )
+    )
+  )
+  
+  # Ensure that the first value really is used
   expect_warning(v1 <-
     pk.tss.stepwise.linear(conc=tmpdata$conc,
                            time=tmpdata$time,
@@ -275,26 +354,31 @@ test_that("pk.tss.stepwise.linear", {
                            verbose=FALSE))
   expect_equal(
     v1,
-    pk.tss.stepwise.linear(conc=tmpdata$conc,
-                           time=tmpdata$time,
-                           subject=tmpdata$subject,
-                           treatment=tmpdata$treatment,
-                           time.dosing=0:14,
-                           level=0.8,
-                           verbose=FALSE),
-    info="pk.tss.stepwise.linear 10")
+    pk.tss.stepwise.linear(
+      conc=tmpdata$conc,
+      time=tmpdata$time,
+      subject=tmpdata$subject,
+      treatment=tmpdata$treatment,
+      time.dosing=0:14,
+      level=0.8,
+      verbose=FALSE
+    )
+  )
 
-  ## Confirm testing for minimum number of data points
+  # Confirm testing for minimum number of data points
   expect_warning(
-    v1 <- pk.tss.stepwise.linear(conc=tmpdata$conc,
-                                 time=tmpdata$time,
-                                 subject=tmpdata$subject,
-                                 treatment=tmpdata$treatment,
-                                 time.dosing=0:1,
-                                 min.points=3,
-                                 level=0.99,
-                                 verbose=FALSE),
-    regexp="After removing non-dosing time points, insufficient data remains for tss calculation")
+    v1 <- pk.tss.stepwise.linear(
+      conc=tmpdata$conc,
+      time=tmpdata$time,
+      subject=tmpdata$subject,
+      treatment=tmpdata$treatment,
+      time.dosing=0:1,
+      min.points=3,
+      level=0.99,
+      verbose=FALSE
+    ),
+    regexp="After removing non-dosing time points, insufficient data remains for tss calculation"
+  )
   expect_equal(v1, NA)
   expect_warning(
     pk.tss.stepwise.linear(conc=tmpdata$conc,
@@ -307,21 +391,24 @@ test_that("pk.tss.stepwise.linear", {
                            verbose=FALSE),
     regexp="After removing non-dosing time points, insufficient data remains for tss calculation")
 
-  ## Confirm the glm model works when subject-level data is not given.
-  expect_equal(
-    pk.tss.stepwise.linear(conc=tmpdata$conc,
-                           time=tmpdata$time,
-                           treatment=tmpdata$treatment,
-                           time.dosing=0:14,
-                           verbose=FALSE),
-    data.frame(tss.stepwise.linear=5),
-    info="pk.tss.stepwise.linear no subject")
+  # Confirm the glm model works when subject-level data is not given.
+  suppressMessages(
+    expect_equal(
+      pk.tss.stepwise.linear(conc=tmpdata$conc,
+                             time=tmpdata$time,
+                             treatment=tmpdata$treatment,
+                             time.dosing=0:14,
+                             verbose=FALSE),
+      data.frame(tss.stepwise.linear=5),
+      info="pk.tss.stepwise.linear no subject"
+    )
+  )
 })
 
 test_that("pk.tss.monoexponential", {
   tmpdata <- generate.data()
-  expect_equal(
-    expect_warning(
+  expect_warning(
+    expect_equal(
       pk.tss.monoexponential(
         conc=tmpdata$conc,
         time=tmpdata$time,
@@ -329,40 +416,111 @@ test_that("pk.tss.monoexponential", {
         treatment=tmpdata$treatment,
         time.dosing=0:14,
         verbose=FALSE
-      )
+      ),
+      data.frame(
+        subject=factor(as.character(c(1, 10, 2:9))),
+        tss.monoexponential.population=4.57618156812974,
+        tss.monoexponential.popind=c(
+          5.14156352865421, 4.64862524830397, 4.45956707917941,
+          4.41492203844343, 4.6782583033301, 4.0823047621517,
+          4.96242115751172, 4.52424147509819, 3.70338406668837,
+          5.1465280219363),
+        treatment=
+          factor(c("A", "B", "A", "A", "A", "A", "B", "B", "B", "B")),
+        tss.monoexponential.individual=c(
+          5.87784329336254, 4.71066285661623, 4.51882509145954,
+          3.91269286106442, 4.74475071729459, 3.99341726779716,
+          5.08737230904342, 4.50068650719192, 3.4876172020751,
+          5.35051537086801),
+        tss.monoexponential.single=4.56067603534,
+        stringsAsFactors=FALSE
+      ),
+      tolerance=1e-4
+    )
+  )
+  expect_output(
+    expect_equal(
+      pk.tss.monoexponential(
+        conc=c(0, 1000),
+        time=0:1,
+        subject=c(1, 1),
+        treatment=c("A", "A"),
+        time.dosing=0:1,
+        tss.fraction=0.9,
+        output="single"
+      ),
+      data.frame(tss.monoexponential.single=NA_real_),
+      info="Single-subject data fitting works when it does not converge."
+    ),
+    regexp = "approximate covariance matrix for parameter estimates not of full rank"
+  )
+})
+
+test_that("pk.tss.monoexponential corner case tests", {
+  tmpdata <- generate.data()
+  # population output, only
+  expect_warning(
+    expect_equal(
+      pk.tss.monoexponential(
+        conc=tmpdata$conc,
+        time=tmpdata$time,
+        subject=tmpdata$subject,
+        treatment=tmpdata$treatment,
+        time.dosing=0:14,
+        output = "population",
+        verbose=FALSE
+      ),
+      data.frame(
+        subject=factor(as.character(seq_len(10))),
+        tss.monoexponential.population=4.57618156812974,
+        stringsAsFactors=FALSE
+      ),
+      tolerance=1e-4
+    )
+  )
+  # (Pseudo) single treatment, only
+  expect_equal(
+    pk.tss.monoexponential(
+      conc=tmpdata$conc,
+      time=tmpdata$time,
+      subject=tmpdata$subject,
+      time.dosing=0:14,
+      output = "population",
+      verbose=FALSE
     ),
     data.frame(
-      subject=factor(as.character(c(1, 10, 2:9))),
-      tss.monoexponential.population=4.57618156812974,
-      tss.monoexponential.popind=c(
-        5.14156352865421, 4.64862524830397, 4.45956707917941,
-        4.41492203844343, 4.6782583033301, 4.0823047621517,
-        4.96242115751172, 4.52424147509819, 3.70338406668837,
-        5.1465280219363),
-      treatment=
-        factor(c("A", "B", "A", "A", "A", "A", "B", "B", "B", "B")),
-      tss.monoexponential.individual=c(
-        5.87784329336254, 4.71066285661623, 4.51882509145954,
-        3.91269286106442, 4.74475071729459, 3.99341726779716,
-        5.08737230904342, 4.50068650719192, 3.4876172020751,
-        5.35051537086801),
-      tss.monoexponential.single=4.56067603534,
+      subject=factor(as.character(seq_len(10))),
+      tss.monoexponential.population=4.56157960341961,
       stringsAsFactors=FALSE
     ),
-    tolerance=1e-4,
-    check.attributes=FALSE,
-    info="pk.tss.monoexponential 1"
+    tolerance=1e-4
   )
+})
 
-  ## Warnings and errors
-  expect_warning(
+test_that("pk.tss.monoexponential expected warnings and errors", {
+  tmpdata <- generate.data()
+  expect_error(
     pk.tss.monoexponential(conc=tmpdata$conc,
                            time=tmpdata$time,
                            subject=tmpdata$subject,
                            treatment=tmpdata$treatment,
                            time.dosing=0:14,
-                           tss.fraction=c(0.5, 0.8)),
-    regexp="Only first value of tss.fraction is being used")
+                           tss.fraction=factor(1)),
+    regexp="tss.fraction must be a number"
+  )
+  suppressWarnings(
+    expect_warning(
+      pk.tss.monoexponential(
+        conc=tmpdata$conc,
+        time=tmpdata$time,
+        subject=tmpdata$subject,
+        treatment=tmpdata$treatment,
+        time.dosing=0:14,
+        tss.fraction=c(0.5, 0.8)
+      ),
+      regexp="Only first value of tss.fraction is being used"
+    )
+  )
   expect_error(
     pk.tss.monoexponential(conc=tmpdata$conc,
                            time=tmpdata$time,
@@ -395,47 +553,71 @@ test_that("pk.tss.monoexponential", {
                            time.dosing=0:14,
                            tss.fraction=2),
     regexp="tss.fraction must be between 0 and 1, exclusive")
-  expect_warning(
-    pk.tss.monoexponential(conc=tmpdata$conc,
-                           time=tmpdata$time,
-                           subject=tmpdata$subject,
-                           treatment=tmpdata$treatment,
-                           time.dosing=0:14,
-                           tss.fraction=0.5),
-    regexp="tss.fraction is usually >= 0.8")
-  
-  expect_equal(
-    pk.tss.monoexponential(conc=c(0, 1000),
-                           time=0:1,
-                           subject=c(1, 1),
-                           treatment=c("A", "A"),
-                           time.dosing=0:1,
-                           tss.fraction=0.9,
-                           output="single"),
-    data.frame(tss.monoexponential.single=NA_real_),
-    info="Single-subject data fitting works when it does not converge.")
-})
-
-test_that("pk.tss", {
-  ## Ensure that pk.tss will go to the correct type of model
-  tmpdata <- generate.data()
-  expect_equal(
-    expect_warning(
-      pk.tss(conc=tmpdata$conc,
-             time=tmpdata$time,
-             subject=tmpdata$subject,
-             treatment=tmpdata$treatment,
-             time.dosing=0:14,
-             verbose=FALSE,
-             type="monoexponential")
-    ),
+  suppressWarnings(
     expect_warning(
       pk.tss.monoexponential(conc=tmpdata$conc,
                              time=tmpdata$time,
                              subject=tmpdata$subject,
                              treatment=tmpdata$treatment,
                              time.dosing=0:14,
-                             verbose=FALSE)
+                             tss.fraction=0.5),
+      regexp="tss.fraction is usually >= 0.8"
+    )
+  )
+  suppressWarnings(
+    expect_warning(
+      pk.tss.monoexponential(conc=tmpdata$conc,
+                             time=tmpdata$time,
+                             subject=tmpdata$subject,
+                             treatment=tmpdata$treatment,
+                             time.dosing=0:14,
+                             tss.fraction=c(0.5, 0.8)),
+      regexp="Only first value of tss.fraction is being used"
+    )
+  )
+  tmpdata_single_subject <- tmpdata[tmpdata$subject == 1 & tmpdata$treatment == "A", ]
+  expect_warning(
+    tss_single_subject <-
+      pk.tss.monoexponential(
+        conc=tmpdata_single_subject$conc,
+        time=tmpdata_single_subject$time,
+        subject=tmpdata_single_subject$subject,
+        treatment=tmpdata_single_subject$treatment,
+        time.dosing=0:14,
+        tss.fraction=0.8
+      ),
+    regexp="Cannot give 'population', 'popind', or 'individual' output without multiple subjects of data",
+    fixed=TRUE
+  )
+  expect_equal(
+    tss_single_subject,
+    data.frame(tss.monoexponential.single=4.108541),
+    tolerance=1e-5
+  )
+})
+
+test_that("pk.tss", {
+  # Ensure that pk.tss will go to the correct type of model
+  tmpdata <- generate.data()
+  suppressWarnings(
+    expect_equal(
+      pk.tss(
+        conc=tmpdata$conc,
+        time=tmpdata$time,
+        subject=tmpdata$subject,
+        treatment=tmpdata$treatment,
+        time.dosing=0:14,
+        verbose=FALSE,
+        type="monoexponential"
+      ),
+      pk.tss.monoexponential(
+        conc=tmpdata$conc,
+        time=tmpdata$time,
+        subject=tmpdata$subject,
+        treatment=tmpdata$treatment,
+        time.dosing=0:14,
+        verbose=FALSE
+      )
     )
   )
 
@@ -454,31 +636,59 @@ test_that("pk.tss", {
                            time.dosing=0:14,
                            verbose=FALSE))
 
-  ## pk.tss will calculate both if requested
-  expect_equal(
-    expect_warning(
-      pk.tss(conc=tmpdata$conc,
-             time=tmpdata$time,
-             subject=tmpdata$subject,
-             treatment=tmpdata$treatment,
-             time.dosing=0:14,
-             verbose=FALSE,
-             type=c("monoexponential", "stepwise.linear"))
-    ),
-    merge(
-      expect_warning(
-        pk.tss.monoexponential(conc=tmpdata$conc,
-                               time=tmpdata$time,
-                               subject=tmpdata$subject,
-                               treatment=tmpdata$treatment,
-                               time.dosing=0:14,
-                               verbose=FALSE)
+  # pk.tss will calculate both if requested
+  suppressWarnings(
+    expect_equal(
+      pk.tss(
+        conc=tmpdata$conc,
+        time=tmpdata$time,
+        subject=tmpdata$subject,
+        treatment=tmpdata$treatment,
+        time.dosing=0:14,
+        verbose=FALSE,
+        type=c("monoexponential", "stepwise.linear")
       ),
-      pk.tss.stepwise.linear(conc=tmpdata$conc,
-                             time=tmpdata$time,
-                             subject=tmpdata$subject,
-                             treatment=tmpdata$treatment,
-                             time.dosing=0:14,
-                             verbose=FALSE),
-      all=TRUE))
+      merge(
+        pk.tss.monoexponential(
+          conc=tmpdata$conc,
+          time=tmpdata$time,
+          subject=tmpdata$subject,
+          treatment=tmpdata$treatment,
+          time.dosing=0:14,
+          verbose=FALSE
+        ),
+        pk.tss.stepwise.linear(
+          conc=tmpdata$conc,
+          time=tmpdata$time,
+          subject=tmpdata$subject,
+          treatment=tmpdata$treatment,
+          time.dosing=0:14,
+          verbose=FALSE
+        ),
+        all=TRUE
+      )
+    )
+  )
+})
+
+test_that("pk.tss.monoexponential with single-subject data", {
+  d_prep <- datasets::Theoph[datasets::Theoph$Subject %in% 2, ]
+  dose_times <- seq(0, 96-1, by=6)
+  d_multidose <-
+    superposition(
+      conc=d_prep$conc,
+      time=d_prep$Time,
+      tau=96, # 48 hours
+      n.tau=1, # One tau interval (0 to 48 hours)
+      dose.times=dose_times
+    )
+  expect_equal(
+    pk.tss.monoexponential(
+      conc=d_multidose$conc, time=d_multidose$time, subject=rep(1, nrow(d_multidose)),
+      time.dosing=dose_times, subject.dosing=rep(1, length(dose_times)),
+      output="single"
+    ),
+    data.frame(tss.monoexponential.single=22.53),
+    tolerance=0.001
+  )
 })
